@@ -16,9 +16,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 # -------------------------------------------------------------------------
@@ -80,7 +79,13 @@ from ..dialog import InfoDialog, OkDialog, QuestionDialog2
 from ..editors import EditPerson
 from ..glade import Glade
 from ..listmodel import ListModel, NOSORT, TOGGLE
-from gramps.gen.const import URL_WIKISTRING, USER_HOME, WIKI_EXTRAPLUGINS_RAWDATA, COLON
+from gramps.gen.const import (
+    URL_WIKISTRING,
+    URL_MANUAL_PAGE,
+    USER_HOME,
+    WIKI_EXTRAPLUGINS_RAWDATA,
+    COLON,
+)
 from gramps.gen.config import config
 from ..widgets.progressdialog import LongOpStatus, ProgressMonitor, GtkProgressDialog
 
@@ -460,6 +465,7 @@ class AddonManager(ManagedWindow):
         hbox.pack_start(self.status_combo, False, False, 0)
 
         clear = Gtk.Button.new_from_icon_name("edit-clear", Gtk.IconSize.BUTTON)
+        clear.set_tooltip_text(_("Reset addon filters to defaults"))
         clear.connect("clicked", self.__clear_filters)
         hbox.pack_start(clear, False, False, 0)
 
@@ -496,7 +502,8 @@ class AddonManager(ManagedWindow):
         Display the Addon Manager help page.
         """
         display_help(
-            "Gramps_5.2_Wiki_Manual_-_Navigation", "Using_the_Addon_Manager..."
+            URL_MANUAL_PAGE + "_-_Navigation",
+            "Using_the_Addon_Manager...",
         )
 
     def __create_filter_combo(self, store, default):
@@ -699,10 +706,15 @@ class AddonManager(ManagedWindow):
 
         hbox = Gtk.Box()
         add_btn = SimpleButton("list-add", self.__add_project)
+        add_btn.set_tooltip_text(_("Insert a project"))
         del_btn = SimpleButton("list-remove", self.__remove_project)
+        del_btn.set_tooltip_text(_("Remove the selected project"))
         up_btn = SimpleButton("go-up", self.__move_up)
+        up_btn.set_tooltip_text(_("Move project upwards in the list"))
         down_btn = SimpleButton("go-down", self.__move_down)
+        down_btn.set_tooltip_text(_("Move project downwards in the list"))
         restore_btn = SimpleButton("document-revert", self.__restore_defaults)
+        restore_btn.set_tooltip_text(_("Revert to the project defaults"))
         self.buttons = [add_btn, del_btn, up_btn, down_btn, restore_btn]
         for button in self.buttons:
             hbox.pack_start(button, False, False, 0)
@@ -740,6 +752,9 @@ class AddonManager(ManagedWindow):
         row = 1
         install = Gtk.CheckButton()
         install.set_label(_("Allow Gramps to install required Python modules"))
+        install.set_tooltip_text(
+            _("Where possible, try to install any missing prerequisite Python modules")
+        )
         active = config.get("behavior.addons-allow-install")
         install.set_active(active)
         install.connect("toggled", self.install_changed)
@@ -853,8 +868,8 @@ class AddonManager(ManagedWindow):
         if dialog.run() == Gtk.ResponseType.OK:
             if row.project[0] == "":
                 self.project_list.add(row)
-            row.project[0] = name.get_text()
-            row.project[1] = url.get_text()
+            row.project[0] = name.get_text().strip()
+            row.project[1] = url.get_text().strip()
             row.update()
             self.update_project_list()
             self.refresh()
@@ -1254,7 +1269,7 @@ class PluginStatus(ManagedWindow):
         pm.set_pass(total=len(lines), header=_("Reading gramps-project.org..."))
         for line in lines:
             pm.step()
-            if line.startswith("|-") or line.startswith("|}"):
+            if line.startswith(("|-", "|}")):
                 if row != []:
                     rows.append(row)
                 state = "row"
@@ -1308,12 +1323,7 @@ class PluginStatus(ManagedWindow):
                 url = download[1:-1]
                 if " " in url:
                     url, text = url.split(" ", 1)
-            if (
-                url.endswith(".zip")
-                or url.endswith(".ZIP")
-                or url.endswith(".tar.gz")
-                or url.endswith(".tgz")
-            ):
+            if url.endswith((".zip", ".ZIP", ".tar.gz", ".tgz")):
                 # Then this is ok:
                 self.addon_model.append(
                     row=[
@@ -1512,7 +1522,7 @@ class PluginStatus(ManagedWindow):
                 )
 
         success_list = sorted(
-            self.__pmgr.get_success_list(), key=lambda x: (x[0], x[2]._get_name())
+            self.__pmgr.get_success_list(), key=lambda x: (x[0], x[2].name)
         )
         for i in success_list:
             # i = (filename, module, pdata)
