@@ -13,9 +13,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 """
 This module provides a progress dialog for displaying the status of
@@ -432,6 +431,7 @@ class _GtkProgressBar(Gtk.Box):
         # self.set_border_width(24)
 
         self._pbar = Gtk.ProgressBar()
+        self._pbar.set_valign(Gtk.Align.CENTER)
         self._hbox = Gtk.Box()
 
         # Only display the cancel button is the operation
@@ -440,9 +440,9 @@ class _GtkProgressBar(Gtk.Box):
             self._cancel = Gtk.Button.new_with_mnemonic(_("_Cancel"))
             self._cancel.connect("clicked", lambda x: long_op_status.cancel())
             self._cancel.show()
-            self._hbox.pack_end(self._cancel, False, True, 0)
+            self._hbox.pack_end(self._cancel, False, True, 6)
 
-        self._hbox.pack_start(self._pbar, True, True, 0)
+        self._hbox.pack_start(self._pbar, True, True, 6)
 
         self.pack_start(self._lbl, False, False, 0)
         self.pack_start(self._hbox, False, False, 0)
